﻿using UnityEngine;
using System.Collections;
using System;
using System.Collections.Generic;


   /*script to detect if the attached gameObject is being clicked by the user, applied
    to an individual gizmo element.*/

    public class GizmoClickDetection : MonoBehaviour {

   //check if click on one handle
    public static bool ALREADY_CLICKED;
    
    // Camera that has been set to the gizmo layer
     public Camera gizmoCamera;

    //Layer upon which gizmos sit
    public LayerMask gizmoLayer;

    //Targets to detect clicks, and highlight when a click is detected
    public GameObject[] targets;

    //Highlight material
    public Material highlight;

    //Dictionary of precedin materials before a highlight
    public Dictionary<MeshRenderer, Material> previousMaterials;

    //check if the user is currently pressing
    [HideInInspector]
    public bool pressing = false;

    //check if the user pressing the plane area
    [HideInInspector]
    public bool pressingPlane = false;

    //On wake-up
    public void Awake() {
        previousMaterials = new Dictionary<MeshRenderer, Material>();
        gizmoCamera = FindObjectOfType<Camera>();
    }

    //Checks for hits on the target objects, highlight when found
	public void Update () {

        // If the left mouse button is pressed      
        if (!ALREADY_CLICKED && Input.GetMouseButtonDown(0)) {         

            // Detect the object(s) the user has clicked
            Ray ray = gizmoCamera.ScreenPointToRay(Input.mousePosition);
            RaycastHit[] hits = Physics.RaycastAll(ray, gizmoLayer);
            bool detected = false;
            pressingPlane = false;

            // Check if object are our targets (skipthe collision if the renderer isn't enabled)
            foreach (RaycastHit hit in hits) {
                if (Array.IndexOf(targets, hit.collider.gameObject) >= 0) {
                    if (!hit.collider.gameObject.GetComponent<Renderer>().enabled) continue;
                    if (hit.collider.gameObject.name.Contains("_plane_")) pressingPlane = true;
                    detected = true;
                    pressing = true;
                }
            }

            if(detected) {
                // Store the current materials of the targets, then highlight them
                if(previousMaterials != null) previousMaterials.Clear();

                foreach (GameObject target in targets) {

                    try {
                        foreach (MeshRenderer renderer in target.GetComponentsInChildren<MeshRenderer>(false)) {
                            previousMaterials[renderer] = renderer.sharedMaterial;
                            renderer.material = highlight;
                        }
                    } catch (NullReferenceException exception) {
                        //no previous materials could be found?
                    }

                }

                ALREADY_CLICKED = true;
            }


        } else if(Input.GetMouseButtonUp(0) && previousMaterials.Count > 0) {
            // If the left mouse button was released and we haven't un-highlighted yet 
             
            foreach (MeshRenderer renderer in previousMaterials.Keys) {
                renderer.material = previousMaterials[renderer];
            }
            previousMaterials.Clear();
            pressing = false;
            pressingPlane = false;
            ALREADY_CLICKED = false;
        }
	}

}

